	PROGRAM PROG104

C	BY A.K. COKER 
C	A.K.C. TECHNOLOGY, 2010
C	WEST MIDLANDS, U.K.



C	RAPID ESTIMATES OF MULTICOMPONENT DISTILLATION AND
C	MINIMUM TRAYS IN DISTILLATION COLUMNS
C	THIS PROGRAM WILL CALCULATE THE FEED COMPONENT RECOVERY
C	IN BOTH THE COLUMN DISTILLATE AND BOTTOMS PRODUCTS AND
C	ESTIMATE THE MINIMUM NUMBER OF STAGES NEEDED TO PERFORM
C	THE GIVEN SEPARATION.
C	FEED STREAMS CONTAINING UP TO 12 COMPONENTS CAN BE HANDLED
C	BY THIS PROGRAM.
C
C	THE FOLLOWING ASSUMPTIONS FOR THIS PROGRAM ARE:
C     
C	1.  THERE IS ONLY ONE FEED STREAM WITH 12 OR FEWER COMPONENTS.
C	2.  THERE IS ONLY ONE HEAVY KEY COMPONENT.
C	3.  FEED COMPONENTS ARE ARRANGED IN ORDER OF DECREASING
C	    RELATIVE VOLATILITY, WITH THE LIGHT KEY (LK) AND HEAVY KEY
C	    (HK) COMPONENTS SHOWN ADJACENT TO EACH OTHER.
C	4.  THE FEED ENTERS THE COLUMN AT THE OPTIMAL STAGE.
C	5.  THE COLUMN PRODUCES TWO PRODUCTS (DISTILLATE AND BOTTOMS)
C	    WITH OVERHEAD CONDENSER AND BOTTOM REBOILER.
C	********************************************************************
C	ALPHAi	=   RELATIVE VOLATILITY OF COMPONENT i
C	Ki	=   EQUILIBRIUM CONSTANT FOR COMPONENT i IN THE FEED STREAM
C	KHK	=   EQUILIBRIUM CONSTANT FOR HEAVY KEY COMPONENT
C		    IN THE FEED STREAM
C	Di	=   COMPONENT i IN DISTILLATE, MOL
C	Bi	=   COMPONENT i IN BOTTOMS, MOL
C	BHK	=   HEAVY KEY COMPONENT IN BOTTOMS, MOL
C	FHK	=   HEAVY KEY COMPONENT IN THE FEED, MOL
C	DLK	=   LIGHT KEY COMPONENT IN DISTILLATE, MOL
C	FLK	=   LIGHT KEY COMPONENT IN THE FEED, MOL
C	ALPHA(LK)=  RELATIVE VOLATILITY OF LIGHT KEY COMPONENT
C	Fi	=   COMPONENT i IN THE FEED
C	NUM1	=   MINIMUM TRAYS AT TOTAL REFLUX
C	DHK	=   HEAVY KEY COMPONENT IN DISTILLATE, MOL
C	BLK	=   LIGHT KEY COMPONENT IN BOTTOMS, MOL
C	A,B	=   CORRELATION CONSTANTS
C	Q	=   FEED THERMAL CONDITION (RATIO OF LIQUID TO VAPOR
C		    FOR THE FEED)
C	RECLK	=   THE PERCENTAGE RECOVERY OF THE LIGHT KEY COMPONENT
C	RECHK	=   THE PERCENTAGE RECOVERY OF THE HEAVY KEY COMPONENT
C	FACTOR	=   FACTOR FOR THE REFLUX RATIO (i.e. FACTOR*MREF)
C	FEED	=   THE	POSITION OF THE FEED PLATE
C	CHOICE	=   DETERMINE WHETHER FEED IS EQUILIBRIUM CONSTANT OR
C		    RELATIVE VOLATILITY.
C	***************************************************************
C
	CHARACTER*5 CHOICE

	DIMENSION ALPHA(20), B(20), D(20), F(20), PERD(20), PERB(20)

	DIMENSION XF(20), XB(20), XD(20)

	REAL K(20), MB(20), MD(20), NUM1, MREF

	COMMON/DATA1/NUM, F, K, RECLK, RECHK, K1, Q
	
	COMMON/DATA2/NTYPE
	
	COMMON/DATA3/FACTOR
	
	COMMON/DATA4/THETA, FEED
	
	COMMON/DATA5/SUMFD
	
	COMMON/DATA6/XF, XD, XB


	OPEN(UNIT=3,FILE='DATA104.DAT',STATUS='OLD',ACTION='READ',
     *	ERR=18)



	
C	
C
C	READ THE CHOICE OF PARAMETER e.g. RELATIVE VOLATILITY (REL) OR
C	EQUILIBRIUM CONSTANT (EQUIL).
C	READ THE TOTAL NUMBER OF COMPONENTS, NUM
C	READ THE FEED AND RELATIVE VOLATILITY OR EQUILIBRIUM CONSTANT, F,K
C	READ THE RECOVERIES OF LIGHT AND HEAVY KEYS, RECLK, RECHK.
C	READ THE POSITION OF THE HEAVY KEY COMPONENT, K1.
C	READ THE THERMAL FEED CONDITION, Q
C	READ THE FACTOR FOR THE REFLUX RATIO, FACTOR.

	READ (3, 5, ERR=19) CHOICE

 5	FORMAT (A)

	IF (CHOICE .EQ. 'REL' .OR. CHOICE .EQ. 'rel') THEN

C	READ THE TOTAL NUMBER OF COMPONENTS

	READ (3, *, ERR=19) NUM

C	READ THE FEED AND THE RELATIVE VOLATILITY OF EACH COMPONENT.


	DO I = 1, NUM

	READ (3, *, ERR=19) F(I), K(I)

	END DO

	ELSEIF (CHOICE .EQ. 'EQUIL' .OR. CHOICE .EQ. 'equil') THEN


C	READ THE TOTAL NUMBER OF COMPONENTS.

	READ (3, *, ERR=19) NUM

C	READ THE FEED AND THE EQUILIBRIUM CONSTANT OF EACH COMPONENT.

	DO I = 1, NUM

	READ (3, *, ERR=19) F(I), K(I)

	END DO

	ENDIF

C	READ THE RECOVERIES OF THE LIGHT AND HEAVY COMPONENTS.


	READ (3, *, ERR=19) RECLK, RECHK

C	READ THE POSITION OF THE HEAVY KEY COMPONENT.
C	READ THE THERMAL CONDITION OF THE FEED.
C	READ THE FACTOR FOR THE REFLUX RATIO.


	READ (3, *, ERR=19) K1, Q, FACTOR

	GO TO 10

 18	WRITE (*, 22)
 22	FORMAT (5X, 'DATA FILE DOES NOT EXIST')
	GO TO 999

 19	WRITE (*, 23)
 23	FORMAT (5X, 'ERROR MESSAGE IN THE DATA VALUE')
	GO TO 999



C       ARRANGE THE FEEDS AND EQUILIBRIUM CONSTANT/RELATIVE
C       VOLATILITY IN THE ORDER OF DECREASING VALUE



 10	CALL SORT (K, F, NUM)


C	CHECK WHETHER EQUILIBRIUM CONSTANTS OR RELATIVE VOLATILITY
C	IS CHOSEN WITH THE FEED COMPONENTS

	IF ( CHOICE .EQ. 'EQUIL' .OR. CHOICE .EQ. 'equil') THEN

	     GO TO 15

	ELSEIF (CHOICE .EQ. 'REL' .OR. CHOICE .EQ. 'rel') THEN

	DO I = 1, NUM

  	      ALPHA(I)=K(I)

	END DO

	ENDIF
	      GO TO 25

C	CALCULATE THE RELATIVE VOLATILITIES OF THE COMPONENTS
C	EQUILIBRIUM VALUES OF THE LIGHT KEY AND HEAVY KEY COMPONENTS ARE:

 15	DO I = 1, NUM

	ALPHA(I)=K(I)/K(K1)

	END DO

C	CALCULATE THE CORRELATION CONSTANTS: A1,B1


 25	A1=ALOG10((1.0-RECHK)/RECHK)

	VAL1=(RECLK/(1.0-RECLK))*(RECHK/(1.0-RECHK))

	B1=ALOG10(VAL1)/ALOG10(ALPHA(K1-1))

C	CALCULATE THE COMPONENT MOLES IN THE DISTILLATE

	DO I = 1, NUM

	D(I)=((10**A1)*(ALPHA(I)**B1))/(1.0+((10**A1)*(ALPHA(I)**B1)))

	PERD(I)=D(I)*100.0

	MD(I)=D(I)*F(I)

	END DO

C	CALCULATE THE RECOVERY OF THE LIGHT KEY COMPONENT IN THE
C	DISTILLATE

	K2=K1-1

	D(K2)=F(K2)*RECLK

C	CALCULATE THE TOTAL MOLES IN THE DISTILLATE

	SUM1=0.0

	DO I = 1, NUM

	  SUM1=SUM1+MD(I)

	END DO

C	CALCULATE THE PERCENTAGE RECOVERY IN THE BOTTOMS PRODUCT

	DO I = 1, NUM

	  B(I)=1.0/(1.0+((10**A1)*(ALPHA(I)**B1)))

	  PERB(I)=B(I)*100.0

	  MB(I)=B(I)*F(I)

	END DO

C	CALCULATE THE RECOVERY OF THE HEAVY KEY COMPONENT IN THE BOTTOMS

	B(K1)=F(K1)*RECHK

C	CALCULATE THE TOTAL PRODUCT IN THE BOTTOMS

	SUM2=0.0

	DO I = 1, NUM

          SUM2=SUM2+MB(I)

	END DO
	
	
C	CALCULATE THE TOTAL FEED, MOLS


	SUMFD = SUM1 + SUM2
		

C	CALCULATE THE MINIMUM NUMBER OF TRAYS IN THE COLUMN

	VAL2=(MD(K1-1)/(MD(K1))*(MB(K1)/MB(K1-1)))

	AMIN=ALOG(VAL2)/(ALOG(ALPHA(K1-1)))

	RECLK=RECLK*100.0

	RECHK=RECHK*100.0


C	CALCULATE THE MOLE FRACTIONS IN THE FEED,DISTILLATE AND BOTTOMS


	SUMB=0.0

	SUMD=0.0

	SUMF=0.0

	DO J = 1, NUM

	 SUMB=SUMB+MB(J)

	 SUMD=SUMD+MD(J)

	 SUMF=SUMF+F(J)

	END DO

	DO I = 1, NUM

	 XB(I)=MB(I)/SUMB

	 XD(I)=MD(I)/SUMD

	 XF(I)=F(I)/SUMF

	END DO



	CALL UNDERW (NUM, Q, XF, XD, THETA, MREF, ALPHA, K1)


C	USE McCORMICK'S EQUATION TO DETERMINE GILLILAND'S GRAPHICAL
C	CORRELATION AND HENCE THE EQUILIBRIUM NUMBER OF STAGES.

	REF=FACTOR*MREF

	X=(REF-MREF)/(REF+1.0)

	C=0.105*ALOG10(X)+0.44

	Y=1.0-(X**C)

	NUM1=(Y+AMIN)/(1.0-Y)


C	USE KIRKBRIDE'S EMPIRICAL EQUATION TO ESTIMATE THE POSITION
C	OF THE FEED PLATE.

	Z1=(XF(K1)/XF(K1-1)*(SUM2/SUM1)*(XB(K1-1)/XD(K1))**2)

	C1=0.206*ALOG10(Z1)

	Z2=10**C1

	FEED=(Z2*NUM1)/(1.0+Z2)
C
	CALL OUTPUT(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
     *	SUM1,SUM2,MREF,REF,NUM1,Q)


	CLOSE (3, STATUS='KEEP')
	
	CLOSE (1)

 999	STOP
	END


C	****************************************************************
C	THIS PROGRAM CALCULATES THE FEED COMPONENTS IN ORDER
C	OF DECREASING RELATIVE VOLATILITY.
C	****************************************************************

	SUBROUTINE SORT (X, Y, N)

	DIMENSION X(20), Y(20)

  	    N1=N-1

	DO 10 I=1,N1

  	    I1=I+1

	DO 20 J=I1,N

  	    IF(X(I) .GE. X(J)) THEN

	GO TO 20

	ELSE

	HOLD=X(I)

	X(I)=X(J)

	X(J)=HOLD

	    HOLD=Y(I)

      	    Y(I)=Y(J)

	    Y(J)=HOLD

	    ENDIF

 20	CONTINUE

 10	CONTINUE

	RETURN

	END

C	****************************************************************
C	THIS PROGRAM CALCULATES THE UNDERWOOD CONSTANT THETA, USING THE
C	BINARY SEARCH METHOD AND THE MINIMUM REFLUX RATIO
C	(i.e. AT AN INFINITE NUMBER OF PLATES)
C	****************************************************************

	SUBROUTINE UNDERW (N, Q, XF, XD, THETA, MREF, ALPHA, K1)

	DIMENSION ALPHA(20), XF(20), XD(20)

	REAL MREF,LHS

	THETA1=ALPHA(K1)

	THETA2=ALPHA(K1-1)

	DO 10 I=1,20

	THETA=0.5*(THETA1+THETA2)

	LHS=Q-1.0

	DO J = 1, N

	LHS=LHS+((ALPHA(J)*XF(J))/(ALPHA(J)-THETA))

	END DO

	IF (LHS .LT. 0.0) THEN

	THETA1=THETA

	GO TO 10

	ELSEIF (LHS .GT. 0.0) THEN

	THETA2=THETA

	GO TO 10

        ELSEIF (LHS .EQ. 0.0) THEN

        GO TO 50

        ENDIF

 10     CONTINUE

 50	MREF = -1.0

	DO K = 1, N

	MREF=MREF+((ALPHA(K)*XD(K))/(ALPHA(K)-THETA))

	END DO

	RETURN

	END

C     *****************************************************************
C
C     THIS PROGRAM OUTPUTS THE RESULTS ON THE SCREEN
C     *****************************************************************

      SUBROUTINE OUTPUT(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
     *SUM1,SUM2,MREF,REF,NUM1,Q)

	DIMENSION F(20), ALPHA(20), PERD(20), PERB(20)
	
	DIMENSION XF(20), XD(20), XB(20)
	
	REAL MD(20), MB(20), NUM1, MREF
	
	
	COMMON/DATA3/FACTOR
	
	COMMON/DATA4/THETA, FEED

	COMMON/DATA5/SUMFD

	COMMON/DATA6/ XF, XD, XB

	WRITE (*, 100)
 100	FORMAT(25X,'MULTICOMPONENT SYSTEM FRACTIONATION')

	WRITE (*, 110)
 110	FORMAT(80(1H*))

	WRITE (*, 120)
 120	FORMAT(/,1X,'COMPONENT',7X,'FEED',5X,'REL VOLATILITY',3X,
     *	'DISTILLATE ',8X,'BOTTOMS ')

	WRITE (*, 130)
 130	FORMAT(1X,'NUMBER',9X,'MOLES',7X,'ALPHA',10X,'%',8X,'MOLES',8X,
     *'%',6X,'MOLES')

	WRITE (*, 140)
 140	FORMAT (80(1H-))

	DO 10 I=1,NUM

	WRITE (*, 150) I,F(I),ALPHA(I),PERD(I),MD(I),PERB(I),MB(I)
 150	FORMAT(3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)
 10	CONTINUE

	WRITE (*, 160)
 160	FORMAT (80(1H-))



	WRITE (*, 155) 
 155	FORMAT(///,1X,'COMPONENT',7X,'FEED',3X,'MOL FRACT.', 2X,
     *  'DISTILLATE ',1X, 'MOL FRACT.', 2X,'BOTTOMS',4X, 'MOL. FRACT.')
 	
	
	WRITE (*, 165)
 165	FORMAT(1X,'NUMBER',9X,'MOLES',7X,'XF',10X,'MOLES',8X,'XD',8X,
     *	'MOLES', 6X,'XB')
     
     	WRITE (*, 175)
 175	FORMAT (80(1H-))
 
 	DO I = 1, NUM
 	
 	WRITE (*, 185) I, F(I), XF(I), MD(I), XD(I), MB(I), XB(I)
 185	FORMAT(3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)
 	END DO
	    	
    	WRITE (*, 195)
 195	FORMAT (80(1H-))   	
	


	WRITE (*, 166) Q
 166	FORMAT (//, 3X, 'THE FEED CONDITION, Q:', T60, F9.1)


	WRITE (*, 170) K1
 170	FORMAT(3X,'THE HEAVY KEY COMPONENT NUMBER IS:',T65,I2)

	WRITE (*, 180) RECLK
 180	FORMAT(3X,'PERCENTAGE RECOVERY OF THE LIGHT KEY COMPONENT',/,
     *	3X,'IN THE DISTILLATE IS (%):',T60,F9.2)


	WRITE (*, 190) RECHK
 190	FORMAT(3X,'PERCENTAGE RECOVERY OF THE HEAVY KEY COMPONENT',/,
     *	3X,'IN THE BOTTOMS IS (%):',T60,F9.2)
     



	WRITE (*, 200) SUM1, SUM2, SUMFD
 200	FORMAT (3X,'TOTAL MOLES IN THE DISTILLATE:', T60, F9.4/,
     *	3X,'TOTAL MOLES IN THE BOTTOMS:', T60, F9.4/,
     *	3X,'TOTAL MOLES IN THE FEED:', T60, F9.4)		


     
	WRITE (*, 210) THETA
 210	FORMAT (3X,'UNDERWOOD CONSTANT:', T60, F9.4)
 
 	
 	WRITE (*, 220) FACTOR
 220	FORMAT (3X,'FACTOR FOR THE REFLUX RATIO:', T60, F9.4) 
 
 
 
 	WRITE (*, 230) MREF
 230	FORMAT(3X,'MINIMUM REFLUX RATIO:',T60,F9.4)


	WRITE (*, 240) REF
 240	FORMAT(3X,'ACTUAL REFLUX RATIO:',T60,F9.4)
	
 

	WRITE (*, 250) AMIN
 250	FORMAT(3X,'MINIMUM NUMBER OF STAGES IS:',T60,F9.1)



	WRITE (*, 260) NUM1
 260	FORMAT(3X,'NUMBER OF THEORETICAL PLATES IN THE COLUMN:',T60,F9.1)

	WRITE (*, 270) FEED
 270	FORMAT(3X,'THE POSITION OF THE FEED PLATE IS:',T60,F9.1)

	WRITE (*, 280)
 280	FORMAT (1H ,80(1H-))


	OPEN (UNIT=1, FILE='RES104.RES')


	CALL PAPER (NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,AMIN,
     *		SUM1,SUM2,MREF,REF,NUM1,Q)

	CLOSE (1)

	RETURN

	END

C	*************************************************************
C	THIS PROGRAM PRINTS THE RESULTS ONTO A PRINTER
C	************************************************************

	SUBROUTINE PAPER(NUM,F,ALPHA,PERD,MD,PERB,MB,K1,RECLK,RECHK,
     *	AMIN,SUM1,SUM2,MREF,REF,NUM1,Q)

	DIMENSION F(20), ALPHA(20), PERD(20), PERB(20)

	DIMENSION XF(20), XD(20), XB(20)

	REAL MD(20), MB(20), MREF, NUM1



	COMMON/DATA3/FACTOR
	
	COMMON/DATA4/THETA, FEED

	COMMON/DATA5/SUMFD

	COMMON/DATA6/XF, XD, XB

	WRITE (1, 290)
 290	FORMAT(25X,'MULTICOMPONENT SYSTEM FRACTIONATION')

	WRITE (1, 300)
 300	FORMAT(80(1H*))

	WRITE (1, 310)
 310	FORMAT(/,1X,'COMPONENT',7X,'FEED',5X,'REL VOLATILITY',3X,
     *	'DISTILATTE ',8X,'BOTTOMS ')

	WRITE (1, 320)
 320	FORMAT(1X,'NUMBER',9X,'MOLES',7X,'ALPHA',10X,'%',8X,'MOLES',8X,
     *'%',6X,'MOLES')

	WRITE (1, 330)
 330	FORMAT (80(1H-))

	DO 10 I=1,NUM

	WRITE (1, 340) I,F(I),ALPHA(I),PERD(I),MD(I),PERB(I),MB(I)
 340	FORMAT(3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)
 10	CONTINUE

	WRITE (1, 350)
 350	FORMAT (80(1H-))
 

	WRITE (1, 155) 
 155	FORMAT(///,1X,'COMPONENT',7X,'FEED',3X,'MOL FRACT.', 2X,
     *  'DISTILLATE ',1X, 'MOL FRACT.', 2X,'BOTTOMS',4X, 'MOL. FRACT.')
 	
	
	WRITE (1, 165)
 165	FORMAT(1X,'NUMBER',9X,'MOLES',7X,'XF',10X,'MOLES',8X,'XD',8X,
     *	'MOLES', 6X,'XB')
     
     	WRITE (1, 175)
 175	FORMAT (80(1H-))
 
 	DO I = 1, NUM
 	
 	WRITE (1, 185) I, F(I), XF(I), MD(I), XD(I), MB(I), XB(I)
 185	FORMAT(3X,I2,7X,F9.4,3X,F9.4,3X,F9.4,2X,F9.4,3X,F9.4,2X,F9.4)
 	END DO
	    	
    	WRITE (1, 195)
 195	FORMAT (80(1H-))   	
	

	WRITE (1, 360) Q
 360	FORMAT (/, 3X, 'THE FEED CONDITION, Q:', T60, F9.1)


	WRITE (1, 370) K1
 370	FORMAT(3X,'THE HEAVY KEY COMPONENT NUMBER IS:',T65,I2)

	WRITE (1, 380) RECLK
 380	FORMAT(3X,'PERCENTAGE RECOVERY OF THE LIGHT KEY COMPONENT',/,
     *	3X,'IN THE DISTILLATE IS (%):',T60,F9.2)


	WRITE (1, 390) RECHK
 390	FORMAT(3X,'PERCENTAGE RECOVERY OF THE HEAVY KEY COMPONENT',/,
     *	3X,'IN THE BOTTOMS IS (%):',T60,F9.2)
     



	WRITE (1, 400) SUM1, SUM2, SUMFD
 400	FORMAT (3X,'TOTAL MOLES IN THE DISTILLATE:', T60, F9.4/,
     *	3X,'TOTAL MOLES IN THE BOTTOMS:', T60, F9.4/,
     *	3X,'TOTAL MOLES IN THE FEED:', T60, F9.4)		


     
	WRITE (1, 410) THETA
 410	FORMAT (3X,'UNDERWOOD CONSTANT:', T60, F9.4)
 
 	
 	WRITE (1, 420) FACTOR
 420	FORMAT (3X,'FACTOR FOR THE REFLUX RATIO:', T60, F9.4) 
 
 
 
 	WRITE (1, 430) MREF
 430	FORMAT(3X,'MINIMUM REFLUX RATIO:',T60,F9.4)


	WRITE (1, 440) REF
 440	FORMAT(3X,'ACTUAL REFLUX RATIO:',T60,F9.4)
	
 

	WRITE (1, 450) AMIN
 450	FORMAT(3X,'MINIMUM NUMBER OF STAGES IS:',T60,F9.1)



	WRITE (1, 460) NUM1
 460	FORMAT(3X,'NUMBER OF THEORETICAL PLATES IN THE COLUMN:',T60,F9.1)

	WRITE (1, 470) FEED
 470	FORMAT(3X,'THE POSITION OF THE FEED PLATE IS:',T60,F9.1)

	WRITE (1, 480)
 480	FORMAT (1H ,80(1H-))


	RETURN

	END
